@@ -24,7 +24,7 @@
  *            Old Forge, PA 18518
  */
  
-#include <varconf/Config.h>
+#include <varconf/config.h>
 
 #include <cstdio>
 #include <iostream>
@@ -78,9 +78,9 @@ namespace {
   {
     if (c=='\n') return C_EOL;
     if (isspace(c)) return C_SPACE;
-    if ((c >= 'a') && (c <= 'z') || (c >= 'A') && (c <= 'Z')) return C_ALPHA;
+    if ((c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z')) return C_ALPHA;
     if (isdigit(c)) return C_NUMERIC;
-    if ((c == '-') || (c == '_')) return C_DASH;
+    if (c == '-' || c == '_') return C_DASH;
     if (c == '=') return C_EQ;
     if (c == '"') return C_QUOTE;
     if (c == '[') return C_SQUARE_OPEN;
@@ -205,7 +205,7 @@ int Config::getCmdline(int argc, char** argv, Scope scope)
 {
   int optind = 1;
 
-  for (size_t i = 1; i < (size_t)argc; i++) {
+  for (int i = 1; i < argc; i++) {
     if (argv[i][0] != '-' ) {
        continue;
     }
@@ -243,8 +243,8 @@ int Config::getCmdline(int argc, char** argv, Scope scope)
         name = ((*I).second).first;
         bool needs_value = ((*I).second).second;
 
-        if (needs_value && argv[i+1] != NULL && argv[i+1][0] != '-'
-                         && argv[i+1] != "") {
+        if (needs_value && (i+1) < argc && argv[i+1][0] != 0
+                        && argv[i+1][0] != '-') {
           value = argv[++i];
         } 
         else {
